@@ -54,7 +54,7 @@ public final class Txt_fr implements TxtInterface {
         + "|http://www.superwaba.org"
         + "|" +Version.BUILD_STR
         + "|Ecrit par Mario De Weerd"
-        + "|seesite@bt747.org"
+        + "|m.deweerd@ieee.org"
         + "|Cette application permets le contrle"
         + "|de diffrents types de logger GPS "
         + "|base de chipset MTK. La modification"
@@ -67,7 +67,6 @@ public final class Txt_fr implements TxtInterface {
         "A propos de SuperWaba";
     private static final String ABOUT_SUPERWABA_TXT=
         "SuperWaba Virtual Machine ";
-    @SuppressWarnings("unused")
     private static final String ABOUT_SUPERWABA_TXT_CONTINUE=
           "|Copyright (c)2000-2007"
         + "|Guilherme Campos Hazan"
