@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** m.deweerd@ieee.org ***
+// *** seesite@bt747.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -1326,6 +1326,7 @@ public class AppSettings implements BT747Thread {
 		return Conv.hex2SignedInt(str);
 	}
 
+	@SuppressWarnings("unused")
 	private final void setLocalUIntOpt(final int param, final int src,
 			final int idx, final int size) {
 		setOpt(param, JavaLibBridge.unsigned2hex(src, size), idx, size);
