@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** m.deweerd@ieee.org ***
+// *** seesite@bt747.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -75,6 +75,7 @@ public final class BT747LogConvert extends GPSLogConvertInterface {
 	 */
 	private static final int BUF_SIZE = 0x800;
 
+	@SuppressWarnings("unused")
 	private static final int minValidUtcTime = JavaLibBridge.getDateInstance(1,
 			1, 1995).dateToUTCepoch1970();
 
@@ -287,6 +288,7 @@ public final class BT747LogConvert extends GPSLogConvertInterface {
 				) {
 					int nbrBytes;
 					nbrBytes = getSpecialRecord(bytes, offsetInBuffer, gpsFile);
+					@SuppressWarnings("unused")
 					int fileOffset = nextAddrToRead - sizeToRead
 							+ offsetInBuffer;
 					if ((recCount == 0)
@@ -783,6 +785,9 @@ public final class BT747LogConvert extends GPSLogConvertInterface {
 			if ((r.utc & 0x80000000) != 0) {
 				invalidReason += "Invalid time:" + r.utc + ";";
 				valid = false;
+			} else if(r.utc<1230768000) {
+				// Correction for week overflow bug.
+				r.utc+=1024*7*24*3600;
 			}
 		} else {
 			// r.utc = 1000; // Value after earliest date
