@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** m.deweerd@ieee.org ***
+// *** seesite@bt747.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -36,6 +36,7 @@ import bt747.sys.interfaces.BT747Time;
  */
 public final class SkytraqLogConvert extends GPSLogConvertInterface {
 	private static final int X_FF = 0xFF;
+	@SuppressWarnings("unused")
 	private int recordSize = 16;
 	private static final int logFormat = (1 << BT747Constants.FMT_UTC_IDX)
 			| (1 << BT747Constants.FMT_LATITUDE_IDX)
@@ -251,6 +252,13 @@ public final class SkytraqLogConvert extends GPSLogConvertInterface {
 	15, /* 2008 */
 	15, /* 2009 Jan. */
 	16, /* 2010 */
+	16, /* 2011 */
+	16, /* 2012 Juil. */
+	17, /* 2013 */
+	17, /* 2014 */
+	18, /* 2015 Juil. */
+	18, /* 2016 */
+	19, /* 2017 Jan. */
 	};
 	/* First year = 1980 */
 	final static private int[] leapMonth = { 1, /* 1980 Jan. */
@@ -284,6 +292,14 @@ public final class SkytraqLogConvert extends GPSLogConvertInterface {
 	100, /* 2008 */
 	1, /* 2009 Jan. */
 	100, /* 2010 */
+	100, /* 2011 */
+	7, /* 2012 Juil. */
+	100, /* 2013 */
+	100, /* 2014 */
+	7, /* 2015 Juil. */
+	100, /* 2016 */
+	1, /* 2017 Jan. */
+	100, /* 2018 */
 	/*
 	 * Last in table must not be a leap second year for algorithm to work, if
 	 * not, add one year.
