@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** m.deweerd@ieee.org ***
+// *** seesite@bt747.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -210,7 +210,8 @@ public final class WPLogConvert extends GPSLogConvertInterface {
                             int minutes;
                             int seconds;
                             int speed;
-                            int tag;
+                            @SuppressWarnings("unused")
+							int tag;
                             int altitude;
                             
                             int rawTime;
