@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** seesite@bt747.org ***
+// *** m.deweerd@ieee.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -138,8 +138,7 @@ public final class GPSSqlFile extends GPSFile {
     private String satSeperator = ";";
 
     private String tableName = "defaulttable";
-    @SuppressWarnings("unused")
-	private String dbName = "defaultdb";
+    private String dbName = "defaultdb";
 
     /*
      * (non-Javadoc)
