@@ -2,7 +2,7 @@
 // *** BT 747 ***
 // *** April 14, 2007 ***
 // *** (c)2007 Mario De Weerd ***
-// *** seesite@bt747.org ***
+// *** m.deweerd@ieee.org ***
 // *** ********************************************************** ***
 // *** Software is provided "AS IS," without a warranty of any ***
 // *** kind. ALL EXPRESS OR IMPLIED REPRESENTATIONS AND WARRANTIES,***
@@ -18,6 +18,7 @@ import gps.BT747Constants;
 import gps.GpsEvent;
 import gps.convert.Conv;
 import gps.log.in.WindowedFile;
+import gps.mvc.commands.GpsLinkExecCommand;
 import gps.mvc.commands.GpsLinkNmeaCommand;
 
 import bt747.sys.File;
